
#ifndef VIDEO_RESIZER__FILTER__INCLUDED
#define VIDEO_RESIZER__FILTER__INCLUDED

#include <windows.h>
#include <streams.h>
#include <string.h>
#include "registry.h"
#include "VideoResizer_Filter.hpp"

extern input_width;
extern input_height;

    DECLARE_INTERFACE_(IVideoResizer, IUnknown)
    {
        STDMETHOD(get_prefs) (THIS_
                    int fun
                 ) PURE;

        STDMETHOD(set_prefs) (THIS_
                    int fun
                 ) PURE;
    };


class VideoResizer_Filter
	:	public CTransformFilter,
		public IVideoResizer,
		public ISpecifyPropertyPages
{

public:

// creation

	// create an instance
  static CUnknown *WINAPI CreateInstance (LPUNKNOWN owner, HRESULT *result);



// CBaseFilter overrides
	DECLARE_IUNKNOWN

	STDMETHODIMP VideoResizer_Filter::get_prefs( int fun );
	STDMETHODIMP VideoResizer_Filter::set_prefs( int fun );

	// Retrieves an interface and increments the reference count. 
	STDMETHODIMP NonDelegatingQueryInterface (REFIID riid, void** object);

	STDMETHODIMP JoinFilterGraph(IFilterGraph *pGraph, LPCWSTR pName);

	// Verifies that the input pin supports the media type
	virtual HRESULT CheckInputType (const CMediaType* mediaType);

	// Verifies that the output pin supports the media type (not an override)
	virtual HRESULT CheckOutputType (const CMediaType* mediaType);

	// Verifies that the input and output pins support the media type. 
	virtual HRESULT CheckTransform (const CMediaType* inputMediaType, const CMediaType* outputMediaType);

	// Sets the number and size of buffers required for the transfer. 
	virtual HRESULT DecideBufferSize (IMemAllocator* allocator, ALLOCATOR_PROPERTIES* properties); 

	// Returns one of the media types that the output pin supports 
	virtual HRESULT GetMediaType (int position, CMediaType* mediaType);

	// Informs when the media type is established for the connection. 
	virtual HRESULT SetMediaType (PIN_DIRECTION direction, const CMediaType* mediaType);

	// Performs transform operations of the filter. 
	virtual HRESULT Transform (IMediaSample* inSample,  IMediaSample* outSample);


/// ISpecifyPropertyPages interface

	// Fills a counted array of GUID values where each GUID specifies the CLSID of each property page 
	// that can be displayed in the property sheet for this object.
	STDMETHODIMP GetPages (CAUUID* pages);
protected:

// protected creation

	VideoResizer_Filter (LPUNKNOWN owner, HRESULT* result);


private:

// private members

	// set input media type
	HRESULT SetInputMediaType (const CMediaType* mediaType);

	// set output media type
	HRESULT SetOutputMediaType (const CMediaType* mediaType);

	// Prepares the output sample
	HRESULT PrepareOutputSample (IMediaSample* inSample, IMediaSample* outSample);
	
// secret

	// describe incoming video

	// describe outgoing video
	CMediaType			outputMediaType;



// no generated methods
	VideoResizer_Filter (const VideoResizer_Filter&);
	const VideoResizer_Filter& operator = (const VideoResizer_Filter&);


}; // class VideoResizer_Filter

#endif // VIDEO_RESIZER__FILTER__INCLUDED